@@ -9,14 +9,17 @@
 * @copyright  2008 stk2k, sazysoft
 */
 
-class charcoal_InterfaceImplementException extends charcoal_Exception
+class InterfaceImplementException extends CharcoalException
 {
 	public function __construct( $class_name, $interface_name )
 	{
 		$msg = "class[$class_name] must implement interface[$interface_name]";
 
 		parent::__construct( $msg );
+
+		ExceptionStack::push( $this );
 	}
 
 }
 
+return __FILE__;
