@@ -4,12 +4,13 @@
 *
 * PHP version 5
 *
-* @package    components.db
+* @package    form_models
 * @author     stk2k <stk2k@sazysoft.com>
 * @copyright  2008 stk2k, sazysoft
 */
-abstract class charcoal_DefaultFormModel implements charcoal_IFormModel
+abstract class DefaultFormModel extends CharcoalComponent implements IFormModel
 {
+	private $_model_id;
 	private $_class_name;
 	private $_class_vars;
 	private $_annotations;
@@ -19,17 +20,43 @@ abstract class charcoal_DefaultFormModel implements charcoal_IFormModel
 	 */
 	public function __construct()
 	{
+		parent::__construct();
+
 		$this->_class_name = get_class($this);
 		$this->_class_vars = get_class_vars($this->_class_name);
 
 		$this->_annotation_list = array();
 		foreach( $this->_class_vars as $key => $var ){
 			if ( strpos($var,'@') !== FALSE ){
-				$this->_annotations[$key] = charcoal_AnnotationUtil::parse( $key, $var );
+				$this->_annotations[$key] = AnnotationUtil::parse( $key, $var );
 			}
 		}
 	}
 
+	/*
+	 *   եͭDTO
+	 */
+	public function createDTO()
+	{
+		return new DTO();
+	}
+
+	/**
+	 * ǥID
+	 */
+	public function setModelID( $model_id )
+	{
+		$this->_model_id = $model_id;
+	}
+
+	/**
+	 * ǥID
+	 */
+	public function getModelID()
+	{
+		return $this->_model_id;
+	}
+
 	/*
 	 *	ե̾
 	 */
@@ -44,12 +71,28 @@ abstract class charcoal_DefaultFormModel implements charcoal_IFormModel
 		return $table_name;
 	}
 
+	/*
+	 *   action°
+	 */
+	public function getAction()
+	{
+		return $this->getFormAnnotationValue( s('action') );
+	}
+
+	/*
+	 *   action°
+	 */
+	public function setAction( String $action )
+	{
+		$this->setFormAnnotationValue( s('action'), $action );
+	}
+
 	/**
 	 * եɤ¸ߤ뤫
 	 */
-	public function fieldExists( $field_name )
+	public function fieldExists( String $field_name )
 	{
-		return isset($this->_class_vars[$field_name]);
+		return isset($this->_class_vars[ "$field_name" ]);
 	}
 
 	/*
@@ -64,7 +107,7 @@ abstract class charcoal_DefaultFormModel implements charcoal_IFormModel
 			foreach( $annotations as $field => $annot_list ){
 				foreach( $annot_list as $annot ){
 					// @fieldꤵƤե
-					if ( $annot && $annot->getName() === 'field' && $annot->getValue() === NULL ){
+					if ( $annot->getName()->equals( s('field') ) && $annot->getValue()->equals( s('') ) ){
 						$result[] = $field;
 					}
 				}
@@ -86,7 +129,7 @@ abstract class charcoal_DefaultFormModel implements charcoal_IFormModel
 			foreach( $annotations as $field => $annot_list ){
 				foreach( $annot_list as $annot ){
 					// @inputꤵƤե
-					if ( $annot && $annot->getName() === 'input' && $annot->getValue() === NULL ){
+					if ( $annot->getName()->equals( s('input') ) && $annot->getValue()->equals( s('') ) ){
 						$result[] = $field;
 					}
 				}
@@ -99,34 +142,53 @@ abstract class charcoal_DefaultFormModel implements charcoal_IFormModel
 	/*
 	 *   Υơ
 	 */
-	public function getAnnotation( $field, $annotation_name )
+	public function getAnnotation( String $field, String $annotation_name )
 	{
-		if ( !isset($this->_annotations[$field]) ){
+		$annot_map = $this->getAnnotationMap( $field );
+		if ( is_null($annot_map) || !isset($annot_map["$annotation_name"]) ){
 			return NULL;
 		}
-		$annotation_list = $this->_annotations[$field];
-		if ( !isset($annotation_list[$annotation_name]) ){
-			return NULL;
-		}
-		$annot = $annotation_list[$annotation_name];
+		$annot = $annot_map["$annotation_name"];
 		return $annot;
 	}
 
+	/*
+	 *   ꤷեɤΥΥơޥåפ
+	 */
+	public function getAnnotationMap( String $field )
+	{
+		if ( !isset($this->_annotations["$field"]) ){
+			return NULL;
+		}
+		return $this->_annotations["$field"];
+	}
+
 	/*
 	 *   Υơͤ
 	 */
-	public function getAnnotationValue( $field, $annotation_name )
+	public function getAnnotationValue( String $field, String $annotation_name, $defaultValue = NULL )
 	{
 		$annot = $this->getAnnotation( $field, $annotation_name );
 
-		return $annot ? $annot->getValue() : NULL;
+		return $annot ? $annot->getValue() : $defaultValue;
 	}
 
+	/*
+	 *   Υơͤ
+	 */
+	public function setAnnotationValue( String $field, String $annotation_name, String $value )
+	{
+		$annot = $this->getAnnotation( $field, $annotation_name );
+
+		if ( $annot ){
+			$annot->setValue( $value );
+		}
+	}
 
 	/*
 	 *   եॢΥơ
 	 */
-	public function getFormAnnotation( $type )
+	public function getFormAnnotation( String $type )
 	{
 		$field = '___form';
 		return $this->getAnnotation( $field, $type );
@@ -135,12 +197,21 @@ abstract class charcoal_DefaultFormModel implements charcoal_IFormModel
 	/*
 	 *   եॢΥơͤ
 	 */
-	public function getFormAnnotationValue( $type )
+	public function getFormAnnotationValue( String $type )
 	{
-		$field = '___form';
+		$field = s('___form');
 		return $this->getAnnotationValue( $field, $type );
 	}
 
+	/*
+	 *   եॢΥơͤ
+	 */
+	public function setFormAnnotationValue( String $type, String $value )
+	{
+		$field = s('___form');
+		return $this->setAnnotationValue( $field, $type, $value );
+	}
+
 	/*
 	 *   ǥեȤΥץ󥯥饹
 	 */
@@ -162,7 +233,7 @@ abstract class charcoal_DefaultFormModel implements charcoal_IFormModel
 	/*
 	 *   ǥեȤΥեɥ饹
 	 */
-	public function getDefaultFieldClass( $field_type )
+	public function getDefaultFieldClass( String $field_type )
 	{
 		$key = "___default_{$field_type}_class";
 		return isset($this->_class_vars[$key]) ? $this->_class_vars[$key] : NULL;
@@ -171,7 +242,7 @@ abstract class charcoal_DefaultFormModel implements charcoal_IFormModel
 	/*
 	 *   ǥեȤΥեɥ
 	 */
-	public function getDefaultFieldStyle( $field_type )
+	public function getDefaultFieldStyle( String $field_type )
 	{
 		$key = "___default_{$field_type}_style";
 		return isset($this->_class_vars[$key]) ? $this->_class_vars[$key] : NULL;
@@ -181,7 +252,7 @@ abstract class charcoal_DefaultFormModel implements charcoal_IFormModel
 	/*
 	 *   ꥹȤθ
 	 */
-	public function getChoiceList( charcoal_ProcedureContext $context, $list_name )
+	public function getChoiceList( String $list_name )
 	{
 		return NULL;
 	}
@@ -207,3 +278,5 @@ abstract class charcoal_DefaultFormModel implements charcoal_IFormModel
 	}
 
 }
+
+return __FILE__;
\ No newline at end of file
