@@ -11,11 +11,6 @@
 
 interface ITaskManager extends IObject
 {
-	/*
-	 * 󥹥ȥ饯
-	 */
-	public function __construct( Vector $dependency_map );
-
 	/*
 	 *   ޥ͡
 	 */
@@ -26,11 +21,16 @@ interface ITaskManager extends IObject
 	 */
 	public function getTask( String $task_name );
 
+	/*
+	 * ʥåץåȤ
+	 */
+	public function getSnapshot();
+
 	/**
 	 *   ٥ȥǥѥåԤ
 	 *
 	 */
-	public function dispatchEvents( IRequest $request, Vector $events );
+	public function dispatchEvents( IRequest $request );
 
 	/**
 	 *   ٥ȽԤ
