@@ -24,7 +24,7 @@ class DBConfigUpdateTask extends SimpleTask implements ITask
 	/**
 	 * ٥Ȥ
 	 */
-	public function processEvent( IEvent $event )
+	public function processEvent( IEvent $event, TaskSnapshot $snapshot )
 	{
 
 		// եǡ
